==> dev-plugin-android-0.0.2-sources.jar: com/zoyi/channel/plugin/android/activity/chat/model/ChatMessageItem.java <==
package com.zoyi.channel.plugin.android.activity.chat.model;

import com.zoyi.channel.plugin.android.activity.chat.type.MessageType;
import com.zoyi.channel.plugin.android.model.rest.Manager;
import com.zoyi.channel.plugin.android.model.rest.Message;
import com.zoyi.channel.plugin.android.util.CompareUtils;
import com.zoyi.channel.plugin.android.util.TimeUtils;

/**
 * Created by mika on 2016. 12. 8..
 */
public class ChatMessageItem implements MessageItem {
  private Message message;
  private MessageType type;

  public ChatMessageItem() {
  }

  public ChatMessageItem(Message message) {
    this.message = message;

    if (this.message != null && Manager.CLASSNAME.equals(message.getPersonType())) {
      this.type = MessageType.MANAGER_MESSSAGE;
    } else {
      this.type = MessageType.USER_MESSAGE;
    }
  }

  @Override
  public Long getFirst() {
    switch (type) {
      case MANAGER_MESSSAGE:
      case USER_MESSAGE:
        return message.getCreatedAt();

      default:
        return 0L;
    }
  }

  @Override
  public String getSecond() {
    switch (type) {
      case MANAGER_MESSSAGE:
      case USER_MESSAGE:
        return message.getId();

      default:
        return "";
    }
  }

  public Message getMessage() {
    return message;
  }

  public MessageType getType() {
    return type;
  }

  public boolean isConnected(MessageItem p2) {
    if (p2 == null || !(p2 instanceof ChatMessageItem)) {
      return false;
    }

    if (this.getType() != p2.getType()) {
      return false;
    }

    Message m1 = this.message;
    Message m2 = ((ChatMessageItem) p2).getMessage();

    if (this.getType() == MessageType.MANAGER_MESSSAGE) {
      if (m1 == null || m2 == null) {
        return false;
      }
      if (CompareUtils.compare(m1.getPersonId(), m2.getPersonId()) != 0) {
        return false;
      }
    }

    switch (this.getType()) {
      case MANAGER_MESSSAGE:
      case USER_MESSAGE:
        String t1 = TimeUtils.get(TimeUtils.MINUTE_24, m1.getCreatedAt());
        String t2 = TimeUtils.get(TimeUtils.MINUTE_24, m2.getCreatedAt());
        return CompareUtils.compare(t1, t2) == 0;

      default:
        return false;
    }
  }

  public String getPersonType() {
    if (message != null) {
      return message.getPersonType();
    }
    return null;
  }

  public String getPersonId() {
    if (message != null) {
      return message.getPersonId();
    }
    return null;
  }
}

==> dev-plugin-android-0.0.29-sources.jar: com/zoyi/channel/plugin/android/activity/chat/model/ChatMessageItem.java <==
package com.zoyi.channel.plugin.android.activity.chat.model;

import com.zoyi.channel.plugin.android.activity.chat.type.MessageType;
import com.zoyi.channel.plugin.android.model.rest.Manager;
import com.zoyi.channel.plugin.android.model.rest.Message;
import com.zoyi.channel.plugin.android.util.CompareUtils;
import com.zoyi.channel.plugin.android.util.TimeUtils;

/**
 * Created by mika on 2016. 12. 8..
 */
public class ChatMessageItem implements MessageItem {
  private Message message;
  private MessageType type;

  public ChatMessageItem() {
  }

  public ChatMessageItem(Message message) {
    this.message = message;

    if (this.message != null && Manager.CLASSNAME.equals(message.getPersonType())) {
      this.type = MessageType.MANAGER_MESSAGE;
    } else {
      this.type = MessageType.USER_MESSAGE;
    }
  }

  @Override
  public Long getFirst() {
    switch (type) {
      case MANAGER_MESSAGE:
      case USER_MESSAGE:
        return message.getCreatedAt();

      default:
        return 0L;
    }
  }

  @Override
  public String getSecond() {
    switch (type) {
      case MANAGER_MESSAGE:
      case USER_MESSAGE:
        return message.getId();

      default:
        return "";
    }
  }

  public Message getMessage() {
    return message;
  }

  public MessageType getType() {
    return type;
  }

  public boolean isConnected(MessageItem p2) {
    if (p2 == null || !(p2 instanceof ChatMessageItem)) {
      return false;
    }

    if (this.getType() != p2.getType()) {
      return false;
    }

    Message m1 = this.message;
    Message m2 = ((ChatMessageItem) p2).getMessage();

    if (this.getType() == MessageType.MANAGER_MESSAGE) {
      if (m1 == null || m2 == null) {
        return false;
      }
      if (CompareUtils.compare(m1.getPersonId(), m2.getPersonId()) != 0) {
        return false;
      }
    }

    switch (this.getType()) {
      case MANAGER_MESSAGE:
      case USER_MESSAGE:
        String t1 = TimeUtils.get(TimeUtils.MINUTE_24, m1.getCreatedAt());
        String t2 = TimeUtils.get(TimeUtils.MINUTE_24, m2.getCreatedAt());
        return CompareUtils.compare(t1, t2) == 0;

      default:
        return false;
    }
  }

  public String getPersonType() {
    if (message != null) {
      return message.getPersonType();
    }
    return null;
  }

  public String getPersonId() {
    if (message != null) {
      return message.getPersonId();
    }
    return null;
  }
}
